@@ -1,4 +1,4 @@
-// based on http://thejit.org/static/v20/Jit/Examples/Treemap/example2.html
+// based closely on http://thejit.org/static/v20/Jit/Examples/Treemap/example2.html
 var labelType, useGradients, nativeTextSupport, animate;
 
 (function() {
@@ -66,10 +66,15 @@ function bySortedValue(obj, comparitor, callback, context) {
 }
 
 
+
+function request_jit_tree(nodeId, level, depth, onComplete){
+    var params = { };//logarea: 0 };
+    jQuery.getJSON('jit_tree/'+nodeId+'/'+depth, params, onComplete);
+}
+
+
 function init(){
-
-    var levelsToShow = 1;
-
+  var levelsToShow = 2;
   //init TreeMap
   var tm = new $jit.TM.Squarified({
     //where to inject the visualization
@@ -101,11 +106,7 @@ function init(){
     Events: {
       enable: true,
       onClick: function(node) {
-        if(node) {
-            // TODO use https://github.com/browserstate/history.js ?
-            window.history.pushState({ "id":node.id }, "", "/"+node.id+"?"+jQuery('#sizeme_params_form').serialize());
-            tm.enter(node);
-        }
+        if(node) tm.enter(node);
       },
       onRightClick: function() {
         tm.out();
@@ -130,7 +131,7 @@ function init(){
       }
     },
     //duration of the animations
-    duration: 200,
+    duration: 300,
     //Enable tips
     Tips: {
       enable: true,
@@ -158,25 +159,41 @@ function init(){
         if (data.self_size) {
             if (data.kids_size)
                 html += sprintf("Own use:    %s<br />", bytesToSize(data.self_size,2));
+            html += sprintf("<div style=\"color:grey\">");
+            bySortedValue(data.leaves,
+                function(a, b) { return a[1] - b[1] },
+                function(k, v) { html += sprintf(" %9s: %s<br />", k, bytesToSize(v,2));
+            });
+            html += sprintf("</div>");
         }
+        html += "<br />";
 
-        $("#sizeme_data_div").JSONView({
-            "attributes": data.attr,
-            "parts": data.leaves,
-            "depth": data.depth,
-            "kids_node_count": data.kids_node_count,
-            "kids_size_bytes": data.kids_size,
-            "self_size_bytes": data.self_size,
-            "name": data.name,
-            "title": data.title,
-            "parent_id": data.parent_id,
-            "id": sprintf("%s%s", node.id, data._ids_merged ? data._ids_merged : "")
+        html += sprintf("<div style=\"color:grey\">");
+
+    if (1) {
+        html += sprintf("Attributes:<br />");
+        bySortedValue(data.attr,
+            function(a, b) { return a[0] > b[0] ? 1 : a[0] < b[0] ? -1 : 0 },
+            function(k, v) { html += sprintf(" %10s: %5d<br />", k, v);
         });
+        html += "<br />";
+    }
+
+        if (data.child_count) {
+            //html += sprintf("Children: %d of %d<br />", data.child_count, data.kids_node_count);
+            html += sprintf("Children: %d<br />", data.kids_node_count);
+        }
+        html += sprintf("Id: %s%s<br />", node.id, data._ids_merged ? data._ids_merged : "");
+        html += sprintf("Depth: %d<br />", data.depth);
+        html += sprintf("Parent: %d<br />", data.parent_id);
+
+        html += JSON.stringify(data.attr, undefined, 4);
+        //html += JSON.stringify(data, undefined, 4);
+        html += sprintf("</div>");
 
         tip.innerHTML =  html; 
       }  
     },
-
     //Implement this method for retrieving a requested  
     //subtree that has as root a node with id = nodeId,  
     //and level as depth. This method could also make a server-side  
@@ -184,15 +201,14 @@ function init(){
     //callback method should be called.  
     request: function(nodeId, level, onComplete){  
             request_jit_tree(nodeId, level, levelsToShow, function(data) {
-                console.log({ "node": nodeId, "request_jit_tree": data});
-                update_node_path(data);
-                onComplete.onComplete(nodeId, data.nodes);
+                console.log("Fetched node "+nodeId);
+                console.log(data);
+                onComplete.onComplete(nodeId, data);  
             });
             // XXX workaround jit bug where old tooltip is still shown till the
             // mouse moves
             jQuery("#_tooltip").fadeOut("fast");
     },
-
     //Add the name of the node in the corresponding label
     //This method is called once, on label creation and only for DOM labels.
     onCreateLabel: function(domElement, node){
@@ -213,52 +229,15 @@ function init(){
     onPlaceLabel: function(domElement, node){ },
   });
 
-
-function request_jit_tree(nodeId, level, levelsToShow, onComplete){
-    var params = jQuery('#sizeme_params_form').serialize();
-    jQuery.getJSON('jit_tree/'+nodeId+'/'+levelsToShow, params, onComplete);
-}
-
-function request_jit_tree_for_node_and_refresh(nodeId){
-  if (!nodeId)
-      nodeId = 1;
-  console.log({ request_jit_tree_for_node_and_refresh: nodeId });
-  request_jit_tree(nodeId, 0, levelsToShow, function(data) {
-        console.log({ request_jit_tree: data });
-        update_node_path(data);
-        tm.loadJSON(data.nodes);
+  request_jit_tree(1, 0, levelsToShow, function(data) {
+        console.log(data);
+        tm.loadJSON(data);
         tm.refresh();
     });
-}
-
-function update_node_path(data){
-    jQuery("#sizeme_path_ul").html(data.name_path_html);
-    // update #sizeme_path_ul
-    //   <li><a href="#">Home</a> <span class="divider">/</span></li>
-    //   <li><a href="#">Library</a> <span class="divider">/</span></li>
-    //   <li class="active">Data</li>
-}
-
-  request_jit_tree_for_node_and_refresh(window.location.pathname.split('/')[1]); // XXX get from url
 
     //add event to buttons
-    $jit.util.addEvent($jit.id('goto_parent'), 'click', function() {
-        // record new node in history
-        var parents = tm.graph.getNode(tm.clickedNode && tm.clickedNode.id || tm.root).getParents();
-        var parent_id = parents[0].id;
-        window.history.pushState({ "id":parent_id }, "", "/"+parent_id+"?"+jQuery('#sizeme_params_form').serialize());
-        // move out one level with a nice animation
-        tm.out();
-    });
-
-    jQuery('#sizeme_logarea_checkbox').change( function() {
-        request_jit_tree_for_node_and_refresh(tm.clickedNode && tm.clickedNode.id || tm.root);
-    });
-
-    window.onpopstate = function(e) {
-        if (e.state && e.state.id)
-            request_jit_tree_for_node_and_refresh(e.state.id);
-    };
+    $jit.util.addEvent($jit.id('back'), 'click', function() { tm.out() });
+    $jit.util.addEvent($jit.id('logarea'), 'onchange', function() { tm.refresh() });
 
 }
 
